@@ -31,9 +31,14 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "xfdesktop-application.h"
 
+#ifdef ENABLE_FILE_ICONS
+#include "xfdesktop-monitor-chooser-ui.h"
+#endif
+
 int
 main(int argc, char **argv)
 {
@@ -49,9 +54,14 @@ main(int argc, char **argv)
     /* bind gettext textdomain */
     xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
-    app = xfdesktop_application_get();
+#ifdef ENABLE_DESKTOP_ICONS
+    xfdesktop_monitor_chooser_ui_register_resource();
+#endif
 
-    ret = xfdesktop_application_run(app, argc, argv);
+    app = xfdesktop_application_get();
+    g_application_add_option_group(G_APPLICATION(app), xfce_sm_client_get_option_group(argc, argv));
+
+    ret = g_application_run(G_APPLICATION(app), argc, argv);
 
     g_object_unref(app);
 
