@@ -383,6 +383,9 @@ xfdesktop_backdrop_cycler_update_image_file(XfdesktopBackdropCycler *cycler, GFi
     g_return_if_fail(G_IS_FILE(image_file));
 
     if (!xfdesktop_g_file_equal0(cycler->cur_image_file, image_file)) {
+        if (cycler->cur_image_file != NULL) {
+            g_object_unref(cycler->cur_image_file);
+        }
         cycler->cur_image_file = g_object_ref(image_file);
     }
 
@@ -1143,6 +1146,8 @@ xfdesktop_backdrop_cycler_image_filename_changed(XfconfChannel *channel,
     // time to cycle, we block this signal handler temporarily.
     if (G_VALUE_HOLDS_STRING(value)) {
         xfdesktop_backdrop_cycler_set_image_filename(cycler, g_value_get_string(value));
+        // If the user has selected a new file manually, reset the timer.
+        xfdesktop_backdrop_cycler_set_timer(cycler, cycler->timer);
     }
 }
 
